const dungeonActivity = document.querySelector("#dungeonActivity");
const dungeonAction = document.querySelector("#dungeonAction");
const dungeonTime = document.querySelector("#dungeonTime");
const floorCount = document.querySelector("#floorCount");
const roomCount = document.querySelector("#roomCount");

// 休息时血量恢复计时器
let restTimer;

let dungeon = {
    rating: 500,
    grade: "E",
    progress: {
        floor: 1,
        room: 1,
        floorLimit: 100,
        roomLimit: 5,
    },
    settings: {
        enemyBaseLvl: 1,
        enemyLvlGap: 5,
        enemyBaseStats: 1,
        enemyScaling: 1.1,
    },
    status: {
        exploring: false,
        paused: true,
        event: false,
    },
    statistics: {
        kills: 0,
        runtime: 0,
    },
    backlog: [],
    action: 0,
};

// ===== Dungeon Setup =====
// Enables start and pause on button click
dungeonActivity.addEventListener('click', function () {
    dungeonStartPause();
});

// Sets up the initial dungeon
const initialDungeonLoad = () => {
    if (localStorage.getItem("dungeonData") !== null) {
        dungeon = JSON.parse(localStorage.getItem("dungeonData"));
        dungeon.status = {
            exploring: false,
            paused: true,
            event: false,
        };
        updateDungeonLog();
    }
    loadDungeonProgress();
    dungeonTime.innerHTML = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
    dungeonTime.innerHTML = "00:00:00";
    dungeonTimer = setInterval(dungeonEvent, 1000);
    playTimer = setInterval(dungeonCounter, 1000);
    
    // 初始化按钮状态
    updateDungeonActivityButton();
    
    // 初始化时如果处于暂停状态，开始休息血量恢复
    if (dungeon.status.paused && !player.inCombat) {
        startResting();
    }
}

// 更新探索按钮状态的函数
const updateDungeonActivityButton = () => {
    // 确保按钮始终可见
    dungeonActivity.style.display = "block";
    dungeonActivity.style.visibility = "visible";
    
    if (dungeon.status.event) {
        // 有事件时，显示事件状态
        dungeonActivity.innerHTML = "处理事件";
        dungeonActivity.style.opacity = "0.7";
        dungeonActivity.disabled = true;
        dungeonAction.innerHTML = "等待选择...";
    } else if (dungeon.status.paused) {
        // 暂停状态
        dungeonActivity.innerHTML = "探索";
        dungeonActivity.style.opacity = "1";
        dungeonActivity.disabled = false;
        dungeonAction.innerHTML = "休息中...";
    } else {
        // 探索状态
        dungeonActivity.innerHTML = "暂停";
        dungeonActivity.style.opacity = "1";
        dungeonActivity.disabled = false;
        dungeonAction.innerHTML = "探索中...";
    }
}

// Start and Pause Functionality
const dungeonStartPause = () => {
    // 调试信息
    console.log('探索按钮点击 - 当前状态:', {
        paused: dungeon.status.paused,
        exploring: dungeon.status.exploring,
        event: dungeon.status.event,
        action: dungeon.action
    });
    
    if (!dungeon.status.paused) {
        // 检查是否有未完成的事件
        if (dungeon.status.event) {
            safePlaySFX(sfxDeny);
            addDungeonLog("<span style='color: #ff6b6b;'><i class='fas fa-exclamation-triangle'></i> 无法休息：必须先处理当前事件！</span>");
            
            // 短暂闪烁按钮提示
            dungeonActivity.style.backgroundColor = "#ff6b6b";
            dungeonActivity.style.color = "white";
            setTimeout(() => {
                dungeonActivity.style.backgroundColor = "";
                dungeonActivity.style.color = "";
                updateDungeonActivityButton(); // 恢复正确状态
            }, 500);
            
            return; // 阻止暂停操作
        }
        
        safePlaySFX(sfxPause);
        dungeon.status.exploring = false;
        dungeon.status.paused = true;
        
        // 开始休息时的血量恢复
        startResting();
    } else {
        safePlaySFX(sfxUnpause);
        dungeon.status.exploring = true;
        dungeon.status.paused = false;
        
        // 停止休息时的血量恢复
        stopResting();
        
        // 安全检查：如果有未完成的事件，清除它
        if (dungeon.status.event) {
            console.warn('警告：开始探索时发现未完成的事件，已清除');
            dungeon.status.event = false;
        }
    }
    
    // 更新按钮状态
    updateDungeonActivityButton();
}

// Counts the total time for the current run and total playtime
const dungeonCounter = () => {
    player.playtime++;
    dungeon.statistics.runtime++;
    dungeonTime.innerHTML = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
    saveData();
}

// Loads the floor and room count
const loadDungeonProgress = () => {
    if (dungeon.progress.room > dungeon.progress.roomLimit) {
        dungeon.progress.room = 1;
        dungeon.progress.floor++;
        
        // 检查是否达到100层通关
        if (dungeon.progress.floor > dungeon.progress.floorLimit) {
            triggerVictory();
            return;
        }
    }
    floorCount.innerHTML = `星区 ${dungeon.progress.floor}`;
    roomCount.innerHTML = `区域 ${dungeon.progress.room}`;
}

// ========== Events in the Dungeon ==========
const dungeonEvent = () => {
    if (dungeon.status.exploring && !dungeon.status.event) {
        dungeon.action++;
        let choices;
        let eventRoll;
        let eventTypes = ["blessing", "curse", "treasure", "enemy", "enemy", "nothing", "nothing", "nothing", "nothing", "monarch"];
        if (dungeon.action > 2 && dungeon.action < 6) {
            eventTypes.push("nextroom");
        } else if (dungeon.action > 5) {
            eventTypes = ["nextroom"];
        }
        const event = eventTypes[Math.floor(Math.random() * eventTypes.length)];

        switch (event) {
            case "nextroom":
                dungeon.status.event = true;
                updateDungeonActivityButton(); // 更新按钮状态
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">进入</button>
                        <button id="choice2">忽略</button>
                    </div>`;
                if (dungeon.progress.room == dungeon.progress.roomLimit) {
                    addDungeonLog(`<span class="Heirloom">你发现了一个不稳定的跃迁点，通往危险的异常空间。</span>`, choices);
                } else {
                    addDungeonLog("你发现了一个跃迁点。", choices);
                }
                document.querySelector("#choice1").onclick = function () {
                    safePlaySFX(sfxConfirm);
                    if (dungeon.progress.room == dungeon.progress.roomLimit) {
                        guardianBattle();
                    } else {
                        eventRoll = randomizeNum(1, 3);
                        if (eventRoll == 1) {
                            incrementRoom();
                            mimicBattle("door");
                            addDungeonLog("你移动到了下一个区域。");
                        } else if (eventRoll == 2) {
                            incrementRoom();
                            choices = `
                                <div class="decision-panel">
                                    <button id="choice1">激活能量箱</button>
                                    <button id="choice2">忽略</button>
                                </div>`;
                            addDungeonLog(`你移动到了下一个区域，发现了一个能量储存室。里面有一个 <i class="fa fa-battery-half"></i>能量箱。`, choices);
                            document.querySelector("#choice1").onclick = function () {
                                safePlaySFX(sfxConfirm);
                                chestEvent();
                            }
                            document.querySelector("#choice2").onclick = function () {
                                safePlaySFX(sfxDecline);
                                dungeon.action = 0;
                                ignoreEvent();
                            };
                        } else {
                            dungeon.status.event = false;
                            incrementRoom();
                            addDungeonLog("你移动到了下一个区域。");
                        }
                    }
                };
                document.querySelector("#choice2").onclick = function () {
                    safePlaySFX(sfxDecline);
                    dungeon.action = 0;
                    ignoreEvent();
                };
                break;
            case "treasure":
                dungeon.status.event = true;
                updateDungeonActivityButton(); // 更新按钮状态
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">激活能量箱</button>
                        <button id="choice2">忽略</button>
                    </div>`;
                addDungeonLog(`你发现了一个能量储存室。里面有一个 <i class="fa fa-battery-half"></i>能量箱。`, choices);
                document.querySelector("#choice1").onclick = function () {
                    safePlaySFX(sfxConfirm);
                    chestEvent();
                }
                document.querySelector("#choice2").onclick = function () {
                    safePlaySFX(sfxDecline);
                    ignoreEvent();
                };
                break;
            case "nothing":
                nothingEvent();
                break;
            case "enemy":
                dungeon.status.event = true;
                updateDungeonActivityButton(); // 更新按钮状态
                choices = `
                    <div class="decision-panel">
                        <button id="choice1">战斗</button>
                        <button id="choice2">逃跑</button>
                    </div>`;
                generateRandomEnemy();
                addDungeonLog(`你遇到了 ${enemy.name}。`, choices);
                player.inCombat = true;
                document.querySelector("#choice1").onclick = function () {
                    safePlaySFX(sfxConfirm);
                    engageBattle();
                }
                document.querySelector("#choice2").onclick = function () {
                    safePlaySFX(sfxDecline);
                    fleeBattle();
                }
                break;
            case "blessing":
                eventRoll = randomizeNum(1, 2);
                if (eventRoll == 1) {
                    dungeon.status.event = true;
                    updateDungeonActivityButton(); // 更新按钮状态
                    blessingValidation();
                    // 确保 player.blessing 是数字类型
                    player.blessing = Number(player.blessing) || 1;
                    let cost = Math.floor(player.blessing * (500 * (player.blessing * 0.5)) + 750);
                    choices = `
                        <div class="decision-panel">
                            <button id="choice1">激活</button>
                            <button id="choice2">忽略</button>
                        </div>`;
                    addDungeonLog(`<span class="Legendary">你发现了一个古代能量节点。你想投入 <i class="fas fa-coins" style="color: #FFD700;"></i><span class="Common">${nFormatter(cost)}</span> 信用点来激活它吗？ (增强等级.${player.blessing})</span>`, choices);
                    document.querySelector("#choice1").onclick = function () {
                        // 确保金币比较时使用数字类型
                        const playerGold = Number(player.gold) || 0;
                        const requiredCost = Number(cost) || 0;
                        console.log(`祝福金币检查 - 玩家金币: ${playerGold}, 需要: ${requiredCost}`);
                        
                        if (playerGold < requiredCost) {
                            safePlaySFX(sfxDeny);
                            addDungeonLog("你没有足够的信用点。");
                        } else {
                            player.gold -= cost;
                            saveData();
                            playerLoadStats();
                            safePlaySFX(sfxConfirm);
                            statBlessing();
                        }
                        
                        // 无论是否有足够金币，都要确保UI状态正确
                        dungeon.status.event = false;
                        updateDungeonActivityButton(); // 更新按钮状态
                        
                        // 确保战斗界面已关闭
                        const combatPanel = document.querySelector('#combatPanel');
                        if (combatPanel && combatPanel.style.display !== 'none') {
                            combatPanel.style.display = 'none';
                        }
                        
                        // 确保页面亮度恢复
                        const dimDungeon = document.querySelector('#dungeon-main');
                        if (dimDungeon && dimDungeon.style.filter !== 'brightness(100%)') {
                            dimDungeon.style.filter = 'brightness(100%)';
                        }
                    }
                    document.querySelector("#choice2").onclick = function () {
                        ignoreEvent();
                    };
                } else {
                    nothingEvent();
                }
                break;
            case "curse":
                eventRoll = randomizeNum(1, 3);
                if (eventRoll == 1) {
                    dungeon.status.event = true;
                    updateDungeonActivityButton(); // 更新按钮状态
                    let curseLvl = Math.round((dungeon.settings.enemyScaling - 1) * 10);
                    let cost = Math.floor(curseLvl * (10000 * (curseLvl * 0.5)) + 5000);
                    choices = `
                            <div class="decision-panel">
                                <button id="choice1">激活</button>
                                <button id="choice2">忽略</button>
                            </div>`;
                    addDungeonLog(`<span class="Heirloom">你发现了一个高能量干扰器。你想投入 <i class="fas fa-coins" style="color: #FFD700;"></i><span class="Common">${nFormatter(cost)}</span> 信用点吗？这将增强敌人但也会提高收获。 (干扰核心.Lv${curseLvl})</span>`, choices);
                    document.querySelector("#choice1").onclick = function () {
                        // 确保金币比较时使用数字类型
                        const playerGold = Number(player.gold) || 0;
                        const requiredCost = Number(cost) || 0;
                        console.log(`诅咒金币检查 - 玩家金币: ${playerGold}, 需要: ${requiredCost}`);
                        
                        if (playerGold < requiredCost) {
                            safePlaySFX(sfxDeny);
                            addDungeonLog("你没有足够的信用点。");
                        } else {
                            player.gold -= cost;
                            saveData();
                            playerLoadStats();
                            safePlaySFX(sfxConfirm);
                            cursedTotem(curseLvl);
                        }
                        
                        // 无论是否有足够金币，都要确保UI状态正确
                        dungeon.status.event = false;
                        updateDungeonActivityButton(); // 更新按钮状态
                        
                        // 确保战斗界面已关闭
                        const combatPanel = document.querySelector('#combatPanel');
                        if (combatPanel && combatPanel.style.display !== 'none') {
                            combatPanel.style.display = 'none';
                        }
                        
                        // 确保页面亮度恢复
                        const dimDungeon = document.querySelector('#dungeon-main');
                        if (dimDungeon && dimDungeon.style.filter !== 'brightness(100%)') {
                            dimDungeon.style.filter = 'brightness(100%)';
                        }
                    }
                    document.querySelector("#choice2").onclick = function () {
                        ignoreEvent();
                    };
                } else {
                    nothingEvent();
                }
                break;
            case "monarch":
                eventRoll = randomizeNum(1, 7);
                if (eventRoll == 1) {
                    dungeon.status.event = true;
                    updateDungeonActivityButton(); // 更新按钮状态
                    choices = `
                            <div class="decision-panel">
                                <button id="choice1">进入</button>
                                <button id="choice2">忽略</button>
                            </div>`;
                    addDungeonLog(`<span class="Heirloom">你发现了一个空间扩张异常。里面似乎有强大的存在正在休眠。</span>`, choices);
                    document.querySelector("#choice1").onclick = function () {
                        safePlaySFX(sfxConfirm);
                        specialBossBattle();
                    }
                    document.querySelector("#choice2").onclick = function () {
                        safePlaySFX(sfxDecline);
                        ignoreEvent();
                    };
                } else {
                    nothingEvent();
                }
        }
    }
}

// ========= Dungeon Choice Events ==========
// Starts the battle
const engageBattle = () => {
    stopResting(); // 停止休息血量恢复
    dungeon.status.event = false; // 清除事件状态
    showCombatInfo();
    startCombat('battleMain');
    addCombatLog(`你遇到了 ${enemy.name}。`);
    updateDungeonLog();
}

// Mimic encounter
const mimicBattle = (type) => {
    stopResting(); // 停止休息血量恢复
    dungeon.status.event = false; // 清除事件状态
    generateRandomEnemy(type);
    showCombatInfo();
    startCombat('battleMain');
    addCombatLog(`你遇到了 ${enemy.name}。`);
    addDungeonLog(`你遇到了 ${enemy.name}。`);
}

// Guardian boss fight
const guardianBattle = () => {
    stopResting(); // 停止休息血量恢复
    incrementRoom();
    generateRandomEnemy("guardian");
    showCombatInfo();
    startCombat('battleGuardian');
    addCombatLog(`星区守护者 ${enemy.name} 正在阻挡你的去路。`);
    addDungeonLog("你移动到了下一层。");
}

// Guardian boss fight
const specialBossBattle = () => {
    stopResting(); // 停止休息血量恢复
    dungeon.status.event = false; // 清除事件状态
    generateRandomEnemy("sboss");
    showCombatInfo();
    startCombat('battleBoss');
    addCombatLog(`空间异常体 ${enemy.name} 被激活了。`);
    addDungeonLog(`空间异常体 ${enemy.name} 被激活了。`);
}

// Flee from the monster
const fleeBattle = () => {
    let eventRoll = randomizeNum(1, 2);
    if (eventRoll == 1) {
        safePlaySFX(sfxConfirm);
        addDungeonLog(`你设法逃跑了。`);
        player.inCombat = false;
        dungeon.status.event = false;
    } else {
        stopResting(); // 停止休息血量恢复
        dungeon.status.event = false; // 清除事件状态
        addDungeonLog(`你逃跑失败！`);
        showCombatInfo();
        startCombat('battleMain');
        addCombatLog(`你遇到了 ${enemy.name}。`);
        addCombatLog(`你逃跑失败！`);
    }
}

// Chest event randomizer
const chestEvent = () => {
    safePlaySFX(sfxConfirm);
    let eventRoll = randomizeNum(1, 4);
    if (eventRoll == 1) {
        mimicBattle("chest");
    } else if (eventRoll == 2) {
        if (dungeon.progress.floor == 1) {
            goldDrop();
            // 金币掉落会显示双倍弹窗，所以不在这里设置event = false
        } else {
            createEquipmentPrint("dungeon");
            dungeon.status.event = false;
        }
    } else if (eventRoll == 3) {
        goldDrop();
        // 金币掉落会显示双倍弹窗，所以不在这里设置event = false
    } else {
        addDungeonLog("能量箱已消耗完毕。");
        dungeon.status.event = false;
    }
}

// Calculates Gold Drop
const goldDrop = () => {
    safePlaySFX(sfxSell);
    let goldValue = Math.max(randomizeNum(50, 500) * safeNumber(dungeon.progress.floor, 1), 50);
    addDungeonLog(`你发现了 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(goldValue)}。`);
    
    // 显示双倍金币选项
    showDoubleGoldOptions(goldValue);
}

// Non choices dungeon event messages
const nothingEvent = () => {
    let eventRoll = randomizeNum(1, 12);
    if (eventRoll == 1) {
        addDungeonLog("你扫描了周围区域，但传感器没有检测到任何异常。");
    } else if (eventRoll == 2) {
        addDungeonLog("你发现了一个空的能量箱。");
    } else if (eventRoll == 3) {
        addDungeonLog("你发现了一具机械残骸，看起来已经停机很久了。");
    } else if (eventRoll == 4) {
        addDungeonLog("你发现了一个失效的探索者动力外骨骼。");
    } else if (eventRoll == 5) {
        addDungeonLog("这个区域的能量读数为零，完全空旷。");
    } else if (eventRoll == 6) {
        addDungeonLog("你检测到了微弱的能量波动，但很快就消失了。");
    } else if (eventRoll == 7) {
        addDungeonLog("你发现了一些散落的金属碎片和烧焦的电路板。");
    } else if (eventRoll == 8) {
        addDungeonLog("雷达显示前方有异常，但抵达后发现只是一些空的储物舱。");
    } else if (eventRoll == 9) {
        addDungeonLog("你发现了一个损坏的数据终端，屏幕闪烁着错误信息。");
    } else if (eventRoll == 10) {
        addDungeonLog("这里有一个废弃的临时营地，设备已经完全断电。");
    } else if (eventRoll == 11) {
        addDungeonLog("你发现了一些深空探索者留下的装备痕迹，但人已经不知去向。");
    } else if (eventRoll == 12) {
        addDungeonLog("传感器检测到了异常的量子波动，但现在已经平静下来。");
    }
}

// Random stat buff
const statBlessing = () => {
    safePlaySFX(sfxBuff);
    let stats = ["hp", "atk", "def", "atkSpd", "vamp", "critRate", "critDmg"];
    let buff = stats[Math.floor(Math.random() * stats.length)];
    let value;
    switch (buff) {
        case "hp":
            value = 10;
            player.bonusStats.hp += value;
            break;
        case "atk":
            value = 8;
            player.bonusStats.atk += value;
            break;
        case "def":
            value = 8;
            player.bonusStats.def += value;
            break;
        case "atkSpd":
            value = 3;
            player.bonusStats.atkSpd += value;
            break;
        case "vamp":
            value = 0.5;
            player.bonusStats.vamp += value;
            break;
        case "critRate":
            value = 1;
            player.bonusStats.critRate += value;
            break;
        case "critDmg":
            value = 6;
            player.bonusStats.critDmg += value;
            break;
    }
    const buffNames = {
        "hp": "装甲完整度",
        "atk": "武器输出",
        "def": "护盾强度",
        "atkSpd": "反应速度",
        "vamp": "纳米修复",
        "critRate": "弱点扫描",
        "critDmg": "爆击倍率"
    };
    addDungeonLog(`系统升级成功！${buffNames[buff]}提升 ${value}%。 (系统强化.Lv${player.blessing} > Lv${player.blessing + 1})`);
    blessingUp();
    playerLoadStats();
    saveData();
}

// Cursed totem offering
const cursedTotem = (curseLvl) => {
    safePlaySFX(sfxBuff);
    dungeon.settings.enemyScaling += 0.1;
    addDungeonLog(`干扰器启动！敌方单位增强，但收益也相应提高。 (干扰核心.Lv${curseLvl} > Lv${curseLvl + 1})`);
    saveData();
}

// Ignore event and proceed exploring
const ignoreEvent = () => {
    safePlaySFX(sfxConfirm);
    dungeon.status.event = false;
    updateDungeonActivityButton(); // 更新按钮状态
    addDungeonLog("你忽略了它，决定继续前进。");
}

// Increase room or floor accordingly
const incrementRoom = () => {
    dungeon.progress.room++;
    dungeon.action = 0;
    loadDungeonProgress();
}

// Increases player total blessing
const blessingUp = () => {
    blessingValidation();
    player.blessing++;
}

// Validates whether blessing exists or not
const blessingValidation = () => {
    if (player.blessing == undefined || isNaN(player.blessing)) {
        player.blessing = 1;
    } else {
        player.blessing = Number(player.blessing);
    }
}

// ========= Dungeon Backlog ==========
// Displays every dungeon activity
const updateDungeonLog = (choices) => {
    let dungeonLog = document.querySelector("#dungeonLog");
    dungeonLog.innerHTML = "";

    // Display the recent 50 dungeon logs
    for (let message of dungeon.backlog.slice(-50)) {
        let logElement = document.createElement("p");
        logElement.innerHTML = message;
        dungeonLog.appendChild(logElement);
    }

    // If the event has choices, display it
    if (typeof choices !== 'undefined') {
        let eventChoices = document.createElement("div");
        eventChoices.innerHTML = choices;
        dungeonLog.appendChild(eventChoices);
    }

    dungeonLog.scrollTop = dungeonLog.scrollHeight;
}

// Add a log to the dungeon backlog
const addDungeonLog = (message, choices) => {
    dungeon.backlog.push(message);
    updateDungeonLog(choices);
}

// Evaluate a dungeon difficulty
const evaluateDungeon = () => {
    let base = 500;
    // Work in Progress
}

// 显示双倍金币选项弹窗
const showDoubleGoldOptions = (baseGold) => {
    safePlaySFX(sfxEncounter);
    
    let modalContent = `
    <div class="content combat">
        <div class="modal-head">
            <h3><i class="fas fa-coins"></i> 信用点发现</h3>
        </div>
        <div class="modal-body">
            <p>你发现了 <span class="highlight">${nFormatter(baseGold)}</span> 信用点！</p>
            <p>连接到量子广告网络可以激活纳米复制器，将信用点翻倍。</p>
            <p class="hint">观看广告（15-30秒）获得双倍奖励</p>
        </div>
        <div class="modal-buttons">
            <button onclick="watchAdForDoubleGold(${baseGold})">
                <i class="fas fa-tv"></i> 激活复制器
            </button>
            <button onclick="collectNormalGold(${baseGold})">
                <i class="fas fa-coins"></i> 收集信用点
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = modalContent;
    document.querySelector("#defaultModal").style.display = "flex";
}

// 观看广告获得双倍金币
const watchAdForDoubleGold = (baseGold) => {
    safePlaySFX(sfxBuff);
    
    // 广告接口预留位置
    // TODO: 在这里调用广告SDK
    // window.showRewardedAd(() => {
    //     // 广告观看成功回调
    //     grantDoubleGold(baseGold);
    // }, () => {
    //     // 广告观看失败回调
    //     showAdError();
    // });
    
    // 临时：直接给予双倍奖励
    grantDoubleGold(baseGold);
}

// 发放双倍金币奖励
const grantDoubleGold = (baseGold) => {
    const doubleGold = baseGold * 2;
    player.gold += doubleGold;
    playerLoadStats();
    
    addDungeonLog(`纳米复制器激活成功！获得 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(doubleGold)}。`);
    
    document.querySelector("#defaultModal").style.display = "none";
    dungeon.status.event = false;
}

// 收集普通金币
const collectNormalGold = (baseGold) => {
    player.gold += baseGold;
    playerLoadStats();
    
    document.querySelector("#defaultModal").style.display = "none";
    dungeon.status.event = false;
}

// 触发胜利条件
const triggerVictory = () => {
    if (typeof sfxBuff !== 'undefined' && sfxBuff.play) {
        safePlaySFX(sfxBuff);
    }
    
    // 停止所有游戏循环
    clearInterval(dungeonTimer);
    clearInterval(playTimer);
    dungeon.status.exploring = false;
    dungeon.status.paused = true;
    
    // 记录通关统计
    if (!player.victoryStats) {
        player.victoryStats = {
            completions: 0,
            fastestTime: null,
            totalKills: 0,
            totalPlaytime: 0
        };
    }
    
    player.victoryStats.completions++;
    player.victoryStats.totalKills += dungeon.statistics.kills;
    player.victoryStats.totalPlaytime += dungeon.statistics.runtime;
    
    if (!player.victoryStats.fastestTime || dungeon.statistics.runtime < player.victoryStats.fastestTime) {
        player.victoryStats.fastestTime = dungeon.statistics.runtime;
    }
    
    saveData();
    showVictoryScreen();
}

// 显示胜利界面
const showVictoryScreen = () => {
    let runTime = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
    let totalPlayTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
    let fastestTime = player.victoryStats.fastestTime ? 
        new Date(player.victoryStats.fastestTime * 1000).toISOString().slice(11, 19) : "N/A";
    
    const victoryModal = `
    <div class="content victory-screen">
        <div class="victory-header">
            <h2><i class="fas fa-trophy"></i> 深空探索完成！</h2>
            <p class="victory-subtitle">你成功探索了全部100个星区！</p>
        </div>
        
        <div class="victory-content">
            <div class="victory-stats">
            <div class="stat-section">
                <h3><i class="fas fa-rocket"></i> 本次探索统计</h3>
                <div class="stat-grid">
                    <div class="stat-item">
                        <span class="stat-label">探索时间</span>
                        <span class="stat-value">${runTime}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">击败敌人</span>
                        <span class="stat-value">${nFormatter(dungeon.statistics.kills)}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">最终等级</span>
                        <span class="stat-value">Lv.${player.lvl}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">系统强化</span>
                        <span class="stat-value">Lv.${player.blessing || 1}</span>
                    </div>
                </div>
            </div>
            
            <div class="stat-section">
                <h3><i class="fas fa-chart-line"></i> 总体成就</h3>
                <div class="stat-grid">
                    <div class="stat-item">
                        <span class="stat-label">完成次数</span>
                        <span class="stat-value">${player.victoryStats.completions}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">最快记录</span>
                        <span class="stat-value">${fastestTime}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">总击杀数</span>
                        <span class="stat-value">${nFormatter(player.kills)}</span>
                    </div>
                    <div class="stat-item">
                        <span class="stat-label">总游戏时间</span>
                        <span class="stat-value">${totalPlayTime}</span>
                    </div>
                </div>
            </div>
        </div>
        </div>
        
        <div class="victory-actions">
            <button id="restart-journey" class="victory-btn primary">
                <i class="fas fa-redo"></i> 重新开始探索
            </button>
            <button id="view-statistics" class="victory-btn secondary">
                <i class="fas fa-chart-bar"></i> 查看详细统计
            </button>
            <button id="return-home" class="victory-btn secondary">
                <i class="fas fa-home"></i> 返回主菜单
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = victoryModal;
    document.querySelector("#defaultModal").style.display = "flex";
    document.querySelector('#dungeon-main').style.filter = "brightness(50%)";
    
    // 胜利界面按钮事件
    document.querySelector("#restart-journey").onclick = function() {
        safePlaySFX(sfxConfirm);
        progressReset();
        allocationPopup();
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#dungeon-main').style.filter = "brightness(100%)";
    };
    
    document.querySelector("#view-statistics").onclick = function() {
        safePlaySFX(sfxOpen);
        showDetailedStatistics();
    };
    
    document.querySelector("#return-home").onclick = function() {
        safePlaySFX(sfxConfirm);
        MusicManager.stopBGM();
        document.querySelector('#dungeon-main').style.display = "none";
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#dungeon-main').style.filter = "brightness(100%)";
        runLoad("title-screen", "flex");
        stopResting(); // 清理休息计时器
        progressReset();
    };
}

// 显示详细统计面板
const showDetailedStatistics = () => {
    let totalPlayTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
    let fastestTime = player.victoryStats?.fastestTime ? 
        new Date(player.victoryStats.fastestTime * 1000).toISOString().slice(11, 19) : "未完成";
    let avgKillsPerRun = player.victoryStats?.completions > 0 ? 
        Math.round(player.victoryStats.totalKills / player.victoryStats.completions) : 0;
    
    const statsModal = `
    <div class="content statistics-mobile">
        <div class="stats-header">
            <h3><i class="fas fa-chart-bar"></i> 探索者档案</h3>
            <button id="close-stats" class="close-btn"><i class="fa fa-xmark"></i></button>
        </div>
        
        <div class="stats-body">
            <div class="stats-section">
                <h4><i class="fas fa-trophy"></i> 成就进度</h4>
                <div class="achievement-grid">
                    <div class="achievement-card ${player.victoryStats?.completions > 0 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-star"></i>
                        <span class="achievement-name">首次通关</span>
                        <span class="achievement-progress">${player.victoryStats?.completions > 0 ? '已完成' : '未完成'}</span>
                    </div>
                    <div class="achievement-card ${player.kills >= 1000 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-skull"></i>
                        <span class="achievement-name">千人斩</span>
                        <span class="achievement-progress">${player.kills >= 1000 ? '已完成' : Math.round(player.kills / 10) + '%'}</span>
                    </div>
                    <div class="achievement-card ${player.victoryStats?.fastestTime && player.victoryStats.fastestTime <= 3600 ? 'unlocked' : 'locked'}">
                        <i class="fas fa-bolt"></i>
                        <span class="achievement-name">极速通关</span>
                        <span class="achievement-progress">${player.victoryStats?.fastestTime && player.victoryStats.fastestTime <= 3600 ? '已完成' : '未完成'}</span>
                    </div>
                </div>
            </div>
            
            <div class="stats-section">
                <h4><i class="fas fa-chart-line"></i> 数据统计</h4>
                <div class="stats-grid">
                    <div class="stat-card">
                        <i class="fas fa-flag-checkered"></i>
                        <span class="stat-value">${player.victoryStats?.completions || 0}</span>
                        <span class="stat-label">通关次数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-stopwatch"></i>
                        <span class="stat-value">${fastestTime}</span>
                        <span class="stat-label">最快记录</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-crosshairs"></i>
                        <span class="stat-value">${nFormatter(player.kills)}</span>
                        <span class="stat-label">击杀总数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-skull-crossbones"></i>
                        <span class="stat-value">${nFormatter(player.deaths)}</span>
                        <span class="stat-label">死亡次数</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-hourglass-half"></i>
                        <span class="stat-value">${totalPlayTime}</span>
                        <span class="stat-label">游戏时长</span>
                    </div>
                    <div class="stat-card">
                        <i class="fas fa-percentage"></i>
                        <span class="stat-value">${player.deaths > 0 ? (player.kills / player.deaths).toFixed(2) : player.kills}</span>
                        <span class="stat-label">K/D 比率</span>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="stats-footer">
            <button id="back-to-victory" class="action-btn">
                <i class="fas fa-arrow-left"></i> 返回
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = statsModal;
    
    document.querySelector("#close-stats").onclick = function() {
        safePlaySFX(sfxDecline);
        showVictoryScreen();
    };
    
    document.querySelector("#back-to-victory").onclick = function() {
        safePlaySFX(sfxDecline);
        showVictoryScreen();
    };
}

// ===== 休息血量恢复系统 =====
const startResting = () => {
    // 清除已存在的休息计时器
    if (restTimer) {
        clearInterval(restTimer);
    }
    
    // 开始血量恢复计时器（每秒恢复1%最大血量）
    restTimer = setInterval(() => {
        if (player && player.stats && !player.inCombat && dungeon.status.paused) {
            const healAmount = Math.round(player.stats.hpMax * 0.01); // 1%最大血量
            
            if (player.stats.hp < player.stats.hpMax) {
                player.stats.hp += healAmount;
                
                // 确保血量不超过上限
                if (player.stats.hp > player.stats.hpMax) {
                    player.stats.hp = player.stats.hpMax;
                }
                
                // 更新界面显示
                playerLoadStats();
                saveData();
            }
        }
    }, 1000); // 每1000毫秒（1秒）执行一次
};

const stopResting = () => {
    if (restTimer) {
        clearInterval(restTimer);
        restTimer = null;
    }
};

// 显示空的统计面板（用于主菜单）
const showEmptyStatistics = () => {
    const player = JSON.parse(localStorage.getItem("playerData"));
    let totalPlayTime = player ? new Date(player.playtime * 1000).toISOString().slice(11, 19) : "00:00:00";
    
    const statsModal = `
    <div class="content statistics-screen">
        <div class="content-head">
            <h3><i class="fas fa-chart-bar"></i> 探索者档案</h3>
            <p id="close-stats"><i class="fa fa-xmark"></i></p>
        </div>
        
        <div class="stats-container">
            <div class="stats-category">
                <h4><i class="fas fa-trophy"></i> 成就进度</h4>
                <div class="achievement-list">
                    <div class="achievement locked">
                        <i class="fas fa-star"></i>
                        <span>首次通关</span>
                        <span class="achievement-status">×</span>
                    </div>
                    <div class="achievement locked">
                        <i class="fas fa-skull"></i>
                        <span>击杀1000敌人</span>
                        <span class="achievement-status">${player ? Math.min(player.kills, 999) : 0}/1000</span>
                    </div>
                    <div class="achievement locked">
                        <i class="fas fa-bolt"></i>
                        <span>1小时通关</span>
                        <span class="achievement-status">×</span>
                    </div>
                </div>
            </div>
            
            <div class="stats-category">
                <h4><i class="fas fa-chart-line"></i> 统计数据</h4>
                <div class="detailed-stats">
                    <div class="stat-row">
                        <span>通关次数</span>
                        <span>0</span>
                    </div>
                    <div class="stat-row">
                        <span>最快记录</span>
                        <span>未完成</span>
                    </div>
                    <div class="stat-row">
                        <span>击杀/死亡</span>
                        <span>${player ? nFormatter(player.kills) : 0}/${player ? nFormatter(player.deaths) : 0}</span>
                    </div>
                    <div class="stat-row">
                        <span>游戏时长</span>
                        <span>${totalPlayTime}</span>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="stats-actions">
            <button id="close-empty-stats" class="stats-btn">
                <i class="fas fa-times"></i> 关闭
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = statsModal;
    document.querySelector("#defaultModal").style.display = "flex";
    
    document.querySelector("#close-stats").onclick = function() {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#title-screen').style.filter = "brightness(100%)";
    };
    
    document.querySelector("#close-empty-stats").onclick = function() {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector('#title-screen').style.filter = "brightness(100%)";
    };
}