window.addEventListener("load", function () {
    // 初始化音频系统
    setVolume();
    
    // 检查隐私政策同意状态
    checkPrivacyConsent();
    
    if (player === null) {
        runLoad("character-creation", "flex");
    } else {
        // 检查是否有未处理的死亡惩罚
        if (player.pendingDeathPenalty) {
            console.log("检测到未处理的死亡惩罚，执行重置");
            progressReset();
            delete player.pendingDeathPenalty;
            saveData();
        }
        let target = document.querySelector("#title-screen");
        target.style.display = "flex";
    }

    // Title Screen Validation
    document.querySelector("#title-screen").addEventListener("click", function () {
        // 确保 Howler 音频上下文被激活
        if (Howler && Howler.ctx && Howler.ctx.state === 'suspended') {
            Howler.ctx.resume().then(() => {
                console.log("音频上下文已激活");
                // 播放一个测试音效来确认音频工作
                safePlaySFX(sfxOpen);
            }).catch(err => {
                console.log("音频上下文激活失败:", err);
            });
        }
        
        const player = JSON.parse(localStorage.getItem("playerData"));
        if (player && player.allocated) {
            enterDungeon();
        } else if (player) {
            allocationPopup();
        }
    });


    // Prevent double-click zooming on mobile devices
    document.ondblclick = function (e) {
        e.preventDefault();
    }

    // Submit Name
    document.querySelector("#name-submit").addEventListener("submit", function (e) {
        e.preventDefault();
        let playerName = document.querySelector("#name-input").value;

        var format = /[!@#$%^&*()_+\-=\[\]{};':"\\|,.<>\/?]+/;
        if (format.test(playerName)) {
            document.querySelector("#alert").innerHTML = "名字不能包含特殊字符！";
        } else {
            if (playerName.length < 1 || playerName.length > 8) {
                document.querySelector("#alert").innerHTML = "名字应该在1-8个字符之间！";
            } else {
                player = {
                    name: playerName,
                    lvl: 1,
                    stats: {
                        hp: null,
                        hpMax: null,
                        atk: null,
                        def: null,
                        pen: null,
                        atkSpd: null,
                        vamp: null,
                        critRate: null,
                        critDmg: null
                    },
                    baseStats: {
                        hp: 500,
                        atk: 100,
                        def: 50,
                        pen: 0,
                        atkSpd: 0.6,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 50
                    },
                    equippedStats: {
                        hp: 0,
                        atk: 0,
                        def: 0,
                        pen: 0,
                        atkSpd: 0,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 0,
                        hpPct: 0,
                        atkPct: 0,
                        defPct: 0,
                        penPct: 0,
                    },
                    bonusStats: {
                        hp: 0,
                        atk: 0,
                        def: 0,
                        atkSpd: 0,
                        vamp: 0,
                        critRate: 0,
                        critDmg: 0
                    },
                    exp: {
                        expCurr: 0,
                        expMax: 100,
                        expCurrLvl: 0,
                        expMaxLvl: 100,
                        lvlGained: 0
                    },
                    inventory: {
                        consumables: [],
                        equipment: []
                    },
                    equipped: [],
                    gold: 0,
                    playtime: 0,
                    kills: 0,
                    deaths: 0,
                    inCombat: false
                };
                calculateStats();
                player.stats.hp = player.stats.hpMax;
                saveData();
                document.querySelector("#character-creation").style.display = "none";
                runLoad("title-screen", "flex");
            }
        }
    });

    // Unequip all items
    document.querySelector("#unequip-all").addEventListener("click", function () {
        safePlaySFX(sfxOpen);

        dungeon.status.exploring = false;
        let dimTarget = document.querySelector('#inventory');
        dimTarget.style.filter = "brightness(50%)";
        defaultModalElement.style.display = "flex";
        defaultModalElement.innerHTML = `
        <div class="content">
            <p>卸下所有物品？</p>
            <div class="button-container">
                <button id="unequip-confirm">卸下</button>
                <button id="unequip-cancel">取消</button>
            </div>
        </div>`;
        let confirm = document.querySelector('#unequip-confirm');
        let cancel = document.querySelector('#unequip-cancel');
        confirm.onclick = function () {
            safePlaySFX(sfxUnequip);
            unequipAll();
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
        };
        cancel.onclick = function () {
            safePlaySFX(sfxDecline);
            continueExploring();
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimTarget.style.filter = "brightness(100%)";
        };
    });

    // 使用事件委托处理系统菜单
    document.addEventListener("click", function (e) {
        if (e.target && e.target.id === "menu-btn") {
            showSystemMenu();
        }
    });
    
    // 系统菜单显示函数
    function showSystemMenu() {
        // 不关闭库存面板，只是调暗背景
        dungeon.status.exploring = false;
        let dimDungeon = document.querySelector('#dungeon-main');
        dimDungeon.style.filter = "brightness(50%)";
        menuModalElement.style.display = "flex";

        // Menu tab
        menuModalElement.innerHTML = `
        <div class="content">
            <div class="content-head">
                <h3>菜单</h3>
                <p id="close-menu"><i class="fa fa-xmark"></i></p>
            </div>
            <button id="player-menu"><i class="fas fa-user"></i>${player.name}</button>
            <button id="stats">当前闯关</button>
            <button id="volume-btn">音量设置</button>
            <button id="quit-run">放弃</button>
        </div>`;

        let close = document.querySelector('#close-menu');
        let playerMenu = document.querySelector('#player-menu');
        let runMenu = document.querySelector('#stats');
        let quitRun = document.querySelector('#quit-run');
        let volumeSettings = document.querySelector('#volume-btn');

        // Player profile click function
        playerMenu.onclick = function () {
            safePlaySFX(sfxOpen);
            let playTime = new Date(player.playtime * 1000).toISOString().slice(11, 19);
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="profile-tab">
                <div class="content-head">
                    <h3>统计信息</h3>
                    <p id="profile-close"><i class="fa fa-xmark"></i></p>
                </div>
                <p>${player.name} Lv.${player.lvl}</p>
                <p>击杀: ${nFormatter(player.kills)}</p>
                <p>死亡: ${nFormatter(player.deaths)}</p>
                <p>游戏时间: ${playTime}</p>
            </div>`;
            let profileTab = document.querySelector('#profile-tab');
            profileTab.style.width = "15rem";
            let profileClose = document.querySelector('#profile-close');
            profileClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Dungeon run click function
        runMenu.onclick = function () {
            safePlaySFX(sfxOpen);
            let runTime = new Date(dungeon.statistics.runtime * 1000).toISOString().slice(11, 19);
            let currentFloor = dungeon.progress.floor;
            let currentRoom = dungeon.progress.room;
            let totalRooms = dungeon.progress.roomLimit;
            let maxFloor = dungeon.progress.floorLimit;
            let killsThisRun = dungeon.statistics.kills;
            let playerDeaths = player.deaths;
            let avgTimePerFloor = dungeon.statistics.runtime > 0 ? (dungeon.statistics.runtime / currentFloor).toFixed(1) : 0;
            
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="run-tab">
                <div class="content-head">
                    <h3><i class="fas fa-chart-line"></i> 当前闯关统计</h3>
                </div>
                
                <div class="stats-container">
                    <div class="stats-section">
                        <h4><i class="fas fa-user"></i> 操作员状态</h4>
                        <p><i class="fas fa-id-badge"></i> ${player.name} Lv.${player.lvl}</p>
                        <p><i class="fas fa-coins"></i> 信用点: ${nFormatter(player.gold)}</p>
                        <p><i class="fas fa-heart"></i> 装甲完整度: ${player.stats.hp}/${player.stats.hpMax}</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-map"></i> 探索进度</h4>
                        <p><i class="fas fa-layer-group"></i> 当前星区: ${currentFloor}/${maxFloor}</p>
                        <p><i class="fas fa-door-open"></i> 区域进度: ${currentRoom}/${totalRooms}</p>
                        <p><i class="fas fa-percentage"></i> 完成度: ${(currentFloor / maxFloor * 100).toFixed(1)}%</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-crosshairs"></i> 战斗数据</h4>
                        <p><i class="fas fa-skull"></i> 本次击杀: ${nFormatter(killsThisRun)}</p>
                        <p><i class="fas fa-heartbeat"></i> 系统崩溃: ${playerDeaths}次</p>
                        <p><i class="fas fa-tachometer-alt"></i> 平均每星区用时: ${avgTimePerFloor}秒</p>
                    </div>

                    <div class="stats-section">
                        <h4><i class="fas fa-cogs"></i> 系统参数</h4>
                        <p><i class="fas fa-arrow-up"></i> 系统强化: Lv.${player.blessing}</p>
                        <p><i class="fas fa-radiation"></i> 干扰核心: Lv.${Math.round((dungeon.settings.enemyScaling - 1) * 10)}</p>
                        <p><i class="fas fa-clock"></i> 运行时间: ${runTime}</p>
                    </div>
                </div>
                
                <button id="run-close" class="bottom-close-btn">退出</button>
            </div>`;
            let runTab = document.querySelector('#run-tab');
            runTab.style.width = "25rem";
            runTab.style.maxWidth = "90vw";
            let runClose = document.querySelector('#run-close');
            runClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Quit the current run
        quitRun.onclick = function () {
            safePlaySFX(sfxOpen);
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content">
                <p>你要放弃这次闯关吗？</p>
                <div class="button-container">
                    <button id="quit-run">放弃</button>
                    <button id="cancel-quit">取消</button>
                </div>
            </div>`;
            let quit = document.querySelector('#quit-run');
            let cancel = document.querySelector('#cancel-quit');
            quit.onclick = function () {
                safePlaySFX(sfxConfirm);
                // Clear out everything, send the player back to meny and clear progress.
                MusicManager.stopBGM();
                let dimDungeon = document.querySelector('#dungeon-main');
                dimDungeon.style.filter = "brightness(100%)";
                dimDungeon.style.display = "none";
                menuModalElement.style.display = "none";
                menuModalElement.innerHTML = "";
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                runLoad("title-screen", "flex");
                clearInterval(dungeonTimer);
                clearInterval(playTimer);
                stopResting(); // 清理休息计时器
                progressReset();
            };
            cancel.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };
        };

        // Opens the volume settings
        volumeSettings.onclick = function () {
            safePlaySFX(sfxOpen);

            let master = volume.master * 100;
            let bgm = volume.bgm * 100;
            let sfx = volume.sfx * 100;
            menuModalElement.style.display = "none";
            defaultModalElement.style.display = "flex";
            defaultModalElement.innerHTML = `
            <div class="content" id="volume-tab">
                <div class="content-head">
                    <h3>音量</h3>
                    <p id="volume-close"><i class="fa fa-xmark"></i></p>
                </div>
                <label id="master-label" for="master-volume">主音量 (${master}%)</label>
                <input type="range" id="master-volume" min="0" max="100" value="${master}">
                <label id="bgm-label" for="bgm-volume">背景音乐 (${bgm}%)</label>
                <input type="range" id="bgm-volume" min="0" max="100" value="${bgm}">
                <label id="sfx-label" for="sfx-volume">音效 (${sfx}%)</label>
                <input type="range" id="sfx-volume" min="0" max="100" value="${sfx}">
                <button id="apply-volume">应用</button>
            </div>`;
            let masterVol = document.querySelector('#master-volume');
            let bgmVol = document.querySelector('#bgm-volume');
            let sfxVol = document.querySelector('#sfx-volume');
            let applyVol = document.querySelector('#apply-volume');
            let volumeTab = document.querySelector('#volume-tab');
            volumeTab.style.width = "15rem";
            let volumeClose = document.querySelector('#volume-close');
            volumeClose.onclick = function () {
                safePlaySFX(sfxDecline);
                defaultModalElement.style.display = "none";
                defaultModalElement.innerHTML = "";
                menuModalElement.style.display = "flex";
            };

            // Volume Control
            masterVol.oninput = function () {
                master = this.value;
                document.querySelector('#master-label').innerHTML = `主音量 (${master}%)`;
            };

            bgmVol.oninput = function () {
                bgm = this.value;
                document.querySelector('#bgm-label').innerHTML = `背景音乐 (${bgm}%)`;
            };

            sfxVol.oninput = function () {
                sfx = this.value;
                document.querySelector('#sfx-label').innerHTML = `音效 (${sfx}%)`;
            };

            applyVol.onclick = function () {
                volume.master = master / 100;
                volume.bgm = bgm / 100;
                volume.sfx = sfx / 100;
                // 重新设置音量并恢复当前音乐
                let wasPlaying = MusicManager.currentBGM && MusicManager.currentBGM.playing();
                let currentType = null;
                if (wasPlaying) {
                    // 确定当前播放的音乐类型
                    for (let type in MusicManager.bgmMap) {
                        if (MusicManager.currentBGM === MusicManager.bgmMap[type]()) {
                            currentType = type;
                            break;
                        }
                    }
                }
                MusicManager.stopBGM();
                setVolume();
                if (currentType && !MusicManager.isPaused) {
                    MusicManager.playBGM(currentType);
                }
                saveData();
            };
        };

        // Close menu
        close.onclick = function () {
            safePlaySFX(sfxDecline);
            continueExploring();
            menuModalElement.style.display = "none";
            menuModalElement.innerHTML = "";
            dimDungeon.style.filter = "brightness(100%)";
        };
    }
});

// Loading Screen
const runLoad = (id, display) => {
    let loader = document.querySelector("#loading");
    loader.style.display = "flex";
    setTimeout(async () => {
        loader.style.display = "none";
        document.querySelector(`#${id}`).style.display = `${display}`;
    }, 1000);
}

// Start the game
const enterDungeon = () => {
    safePlaySFX(sfxConfirm);
    
    // 立即播放音乐（在用户交互的直接上下文中）
    if (!player.inCombat) {
        MusicManager.playBGM('dungeon');
    }
    
    document.querySelector("#title-screen").style.display = "none";
    runLoad("dungeon-main", "flex");
    
    // 延迟执行其他初始化
    setTimeout(() => {
        if (player.inCombat) {
            enemy = JSON.parse(localStorage.getItem("enemyData"));
            showCombatInfo();
            startCombat('battleMain');
        }
        if (player.stats.hp == 0) {
            progressReset();
        }
        initialDungeonLoad();
        playerLoadStats();
    }, 1000);
}

// Save all the data into local storage
const saveData = () => {
    const playerData = JSON.stringify(player);
    const dungeonData = JSON.stringify(dungeon);
    const enemyData = JSON.stringify(enemy);
    const volumeData = JSON.stringify(volume);
    localStorage.setItem("playerData", playerData);
    localStorage.setItem("dungeonData", dungeonData);
    localStorage.setItem("enemyData", enemyData);
    localStorage.setItem("volumeData", volumeData);
}

// Calculate every player stat
const calculateStats = () => {
    let equipmentAtkSpd = player.baseStats.atkSpd * (player.equippedStats.atkSpd / 100);
    let playerHpBase = player.baseStats.hp;
    let playerAtkBase = player.baseStats.atk;
    let playerDefBase = player.baseStats.def;
    let playerAtkSpdBase = player.baseStats.atkSpd;
    let playerVampBase = player.baseStats.vamp;
    let playerCRateBase = player.baseStats.critRate;
    let playerCDmgBase = player.baseStats.critDmg;

    player.stats.hpMax = Math.round((playerHpBase + playerHpBase * (player.bonusStats.hp / 100)) + player.equippedStats.hp);
    player.stats.atk = Math.round((playerAtkBase + playerAtkBase * (player.bonusStats.atk / 100)) + player.equippedStats.atk);
    player.stats.def = Math.round((playerDefBase + playerDefBase * (player.bonusStats.def / 100)) + player.equippedStats.def);
    player.stats.atkSpd = (playerAtkSpdBase + playerAtkSpdBase * (player.bonusStats.atkSpd / 100)) + equipmentAtkSpd + (equipmentAtkSpd * (player.equippedStats.atkSpd / 100));
    player.stats.vamp = playerVampBase + player.bonusStats.vamp + player.equippedStats.vamp;
    player.stats.critRate = playerCRateBase + player.bonusStats.critRate + player.equippedStats.critRate;
    player.stats.critDmg = playerCDmgBase + player.bonusStats.critDmg + player.equippedStats.critDmg;

    // Caps attack speed to 2.5
    if (player.stats.atkSpd > 2.5) {
        player.stats.atkSpd = 2.5;
    }
}

// Resets the progress back to start
const progressReset = () => {
    player.stats.hp = player.stats.hpMax;
    player.lvl = 1;
    player.blessing = 1;
    reviveCount = 0; // 重置复活次数
    player.exp = {
        expCurr: 0,
        expMax: 100,
        expCurrLvl: 0,
        expMaxLvl: 100,
        lvlGained: 0
    };
    player.bonusStats = {
        hp: 0,
        atk: 0,
        def: 0,
        atkSpd: 0,
        vamp: 0,
        critRate: 0,
        critDmg: 0
    };
    player.skills = [];
    player.inCombat = false;
    
    // 死亡惩罚：金币减半，装备保留
    player.gold = Math.floor(player.gold / 2);
    
    dungeon.progress.floor = 1;
    dungeon.progress.room = 1;
    dungeon.statistics.kills = 0;
    dungeon.status = {
        exploring: false,
        paused: true,
        event: false,
    };
    dungeon.settings = {
        enemyBaseLvl: 1,
        enemyLvlGap: 5,
        enemyBaseStats: 1,
        enemyScaling: 1.1,
    };
    delete dungeon.enemyMultipliers;
    delete player.allocated;
    dungeon.backlog.length = 0;
    dungeon.action = 0;
    dungeon.statistics.runtime = 0;
    combatBacklog.length = 0;
    saveData();
}


// Player Stat Allocation
const allocationPopup = () => {
    let allocation = {
        hp: 5,
        atk: 5,
        def: 5,
        atkSpd: 5
    }
    const updateStats = () => {
        stats = {
            hp: 50 * allocation.hp,
            atk: 10 * allocation.atk,
            def: 10 * allocation.def,
            atkSpd: 0.4 + (0.02 * allocation.atkSpd)
        }
    }
    updateStats();
    let points = 20;
    const loadContent = function () {
        defaultModalElement.innerHTML = `
        <div class="content" id="allocate-stats">
            <div class="content-head">
                <h3>系统初始化</h3>
                <p id="allocate-close"><i class="fa fa-xmark"></i></p>
            </div>
            <div class="row">
                <p><i class="fas fa-heart-pulse"></i><span id="hpDisplay">装甲完整度: ${stats.hp}</span></p>
                <div class="row">
                    <button id="hpMin">-</button>
                    <span id="hpAllo">${allocation.hp}</span>
                    <button id="hpAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-bolt"></i><span id="atkDisplay">武器输出: ${stats.atk}W</span></p>
                <div class="row">
                    <button id="atkMin">-</button>
                    <span id="atkAllo">${allocation.atk}</span>
                    <button id="atkAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-shield"></i><span id="defDisplay">护盾强度: ${stats.def}MJ</span></p>
                <div class="row">
                    <button id="defMin">-</button>
                    <span id="defAllo">${allocation.def}</span>
                    <button id="defAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p><i class="fa-solid fa-gauge-high"></i><span id="atkSpdDisplay">反应速度: ${stats.atkSpd}/s</span></p>
                <div class="row">
                    <button id="atkSpdMin">-</button>
                    <span id="atkSpdAllo">${allocation.atkSpd}</span>
                    <button id="atkSpdAdd">+</button>
                </div>
            </div>
            <div class="row">
                <p id="alloPts">可用模块: ${points}</p>
                <button id="allocate-reset">重置</button>
            </div>
            <div class="row">
                <p>增强程序</p>
                <select id="select-skill">
                    <option value="Remnant Razor">等离子刃</option>
                    <option value="Titan's Will">钛合金装甲</option>
                    <option value="Devastator">毁灭者协议</option>
                    <option value="Blade Dance">高频振动</option>
                    <option value="Paladin's Heart">纳米护盾</option>
                    <option value="Aegis Thorns">反应装甲</option>
                </select>
            </div>
            <div class="row primary-panel pad">
                <p id="skill-desc">等离子武器造成目标当前装甲8%的额外伤害。</p>
            </div>
            <button id="allocate-confirm">确认</button>
        </div>`;
    }
    defaultModalElement.style.display = "flex";
    document.querySelector("#title-screen").style.filter = "brightness(50%)";
    loadContent();

    // Stat Allocation
    const handleStatButtons = (e) => {
        let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
        if (e.includes("Add")) {
            let stat = e.split("Add")[0];
            if (points > 0) {
                safePlaySFX(sfxConfirm);
                allocation[stat]++;
                points--;
                updateStats();
                const statDisplayNames = {
                    "hp": "装甲完整度",
                    "atk": "武器输出",
                    "def": "护盾强度",
                    "atkSpd": "反应速度"
                };
                const statUnits = {
                    "hp": "",
                    "atk": "W",
                    "def": "MJ",
                    "atkSpd": "/s"
                };
                document.querySelector(`#${stat}Display`).innerHTML = `${statDisplayNames[stat]}: ${stats[stat].toFixed(2).replace(rx, "$1")}${statUnits[stat]}`;
                document.querySelector(`#${stat}Allo`).innerHTML = allocation[stat];
                document.querySelector(`#alloPts`).innerHTML = `可用模块: ${points}`;
            } else {
                safePlaySFX(sfxDeny);
            }
        } else if (e.includes("Min")) {
            let stat = e.split("Min")[0];
            if (allocation[stat] > 5) {
                safePlaySFX(sfxConfirm);
                allocation[stat]--;
                points++;
                updateStats();
                const statDisplayNames = {
                    "hp": "装甲完整度",
                    "atk": "武器输出",
                    "def": "护盾强度",
                    "atkSpd": "反应速度"
                };
                const statUnits = {
                    "hp": "",
                    "atk": "W",
                    "def": "MJ",
                    "atkSpd": "/s"
                };
                document.querySelector(`#${stat}Display`).innerHTML = `${statDisplayNames[stat]}: ${stats[stat].toFixed(2).replace(rx, "$1")}${statUnits[stat]}`;
                document.querySelector(`#${stat}Allo`).innerHTML = allocation[stat];
                document.querySelector(`#alloPts`).innerHTML = `可用模块: ${points}`;
            } else {
                safePlaySFX(sfxDeny);
            }
        }
    }
    document.querySelector("#hpAdd").onclick = function () {
        handleStatButtons("hpAdd")
    };
    document.querySelector("#hpMin").onclick = function () {
        handleStatButtons("hpMin")
    };
    document.querySelector("#atkAdd").onclick = function () {
        handleStatButtons("atkAdd")
    };
    document.querySelector("#atkMin").onclick = function () {
        handleStatButtons("atkMin")
    };
    document.querySelector("#defAdd").onclick = function () {
        handleStatButtons("defAdd")
    };
    document.querySelector("#defMin").onclick = function () {
        handleStatButtons("defMin")
    };
    document.querySelector("#atkSpdAdd").onclick = function () {
        handleStatButtons("atkSpdAdd")
    };
    document.querySelector("#atkSpdMin").onclick = function () {
        handleStatButtons("atkSpdMin")
    };

    // Passive skills
    let selectSkill = document.querySelector("#select-skill");
    let skillDesc = document.querySelector("#skill-desc");
    selectSkill.onclick = function () {
        safePlaySFX(sfxConfirm);
    }
    selectSkill.onchange = function () {
        safePlaySFX(sfxOpen);
        if (selectSkill.value == "Remnant Razor") {
            skillDesc.innerHTML = "攻击造成额外的敌人当前生命值8%的伤害。";
        }
        if (selectSkill.value == "Titan's Will") {
            skillDesc.innerHTML = "攻击造成额外的你的最大生命值5%的伤害。";
        }
        if (selectSkill.value == "Devastator") {
            skillDesc.innerHTML = "造成额外的30%的伤害，但你失去30%的基础攻击速度。";
        }
        if (selectSkill.value == "Rampager") {
            skillDesc.innerHTML = "每次攻击后攻击力增加5。叠加在战斗后重置。";
        }
        if (selectSkill.value == "Blade Dance") {
            skillDesc.innerHTML = "每次攻击后获得额外的攻击速度。叠加在战斗后重置。";
        }
        if (selectSkill.value == "Paladin's Heart") {
            skillDesc.innerHTML = "你永久性地受到少的25%的伤害。";
        }
        if (selectSkill.value == "Aegis Thorns") {
            skillDesc.innerHTML = "敌人受到他们造成伤害的15%的反弹伤害。";
        }
    }

    // Operation Buttons
    let confirm = document.querySelector("#allocate-confirm");
    let reset = document.querySelector("#allocate-reset");
    let close = document.querySelector("#allocate-close");
    confirm.onclick = function () {
        safePlaySFX(sfxConfirm);
        // Set allocated stats to player base stats
        player.baseStats = {
            hp: stats.hp,
            atk: stats.atk,
            def: stats.def,
            pen: 0,
            atkSpd: stats.atkSpd,
            vamp: 0,
            critRate: 0,
            critDmg: 50
        }

        // Set player skill
        objectValidation();
        if (selectSkill.value == "Remnant Razor") {
            player.skills.push("Remnant Razor");
        }
        if (selectSkill.value == "Titan's Will") {
            player.skills.push("Titan's Will");
        }
        if (selectSkill.value == "Devastator") {
            player.skills.push("Devastator");
            player.baseStats.atkSpd = player.baseStats.atkSpd - ((30 * player.baseStats.atkSpd) / 100);
        }
        if (selectSkill.value == "Rampager") {
            player.skills.push("Rampager");
        }
        if (selectSkill.value == "Blade Dance") {
            player.skills.push("Blade Dance");
        }
        if (selectSkill.value == "Paladin's Heart") {
            player.skills.push("Paladin's Heart");
        }
        if (selectSkill.value == "Aegis Thorns") {
            player.skills.push("Aegis Thorns");
        }

        // Proceed to dungeon
        player.allocated = true;
        enterDungeon();
        player.stats.hp = player.stats.hpMax;
        playerLoadStats();
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        document.querySelector("#title-screen").style.filter = "brightness(100%)";
    }
    reset.onclick = function () {
        safePlaySFX(sfxDecline);
        allocation = {
            hp: 5,
            atk: 5,
            def: 5,
            atkSpd: 5
        };
        points = 20;
        updateStats();

        // Display Reset
        document.querySelector(`#hpDisplay`).innerHTML = `装甲完整度: ${stats.hp}`;
        document.querySelector(`#atkDisplay`).innerHTML = `武器输出: ${stats.atk}W`;
        document.querySelector(`#defDisplay`).innerHTML = `护盾强度: ${stats.def}MJ`;
        document.querySelector(`#atkSpdDisplay`).innerHTML = `反应速度: ${stats.atkSpd}/s`;
        document.querySelector(`#hpAllo`).innerHTML = allocation.hp;
        document.querySelector(`#atkAllo`).innerHTML = allocation.atk;
        document.querySelector(`#defAllo`).innerHTML = allocation.def;
        document.querySelector(`#atkSpdAllo`).innerHTML = allocation.atkSpd;
        document.querySelector(`#alloPts`).innerHTML = `Stat Points: ${points}`;
    }
    close.onclick = function () {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        document.querySelector("#title-screen").style.filter = "brightness(100%)";
    }
}

const objectValidation = () => {
    if (player.skills == undefined) {
        player.skills = [];
    }
    if (player.tempStats == undefined) {
        player.tempStats = {};
        player.tempStats.atk = 0;
        player.tempStats.atkSpd = 0;
    }
    saveData();
}

// 测试模式按键监听 (T, G, V)
document.addEventListener('keydown', function(e) {
    // 只在游戏主界面时生效，且没有输入框聚焦
    const dungeonMain = document.querySelector('#dungeon-main');
    const activeElement = document.activeElement;
    const isInputFocused = activeElement && (activeElement.tagName === 'INPUT' || activeElement.tagName === 'TEXTAREA');
    
    if (dungeonMain && dungeonMain.style.display !== 'none' && !isInputFocused) {
        
        // T 触发测试模式
        if (e.key.toLowerCase() === 't') {
            e.preventDefault();
            showTestModeModal();
        }
        
        // V 直接触发胜利
        if (e.key.toLowerCase() === 'v') {
            e.preventDefault();
            triggerTestVictory();
        }
        
        // G 传送到99层
        if (e.key.toLowerCase() === 'g') {
            e.preventDefault();
            teleportTo99();
        }
        
        // D 调试金币显示
        if (e.key.toLowerCase() === 'd') {
            e.preventDefault();
            debugGoldDisplay();
        }
        
        // E 调试事件状态
        if (e.key.toLowerCase() === 'e') {
            e.preventDefault();
            console.log('=== 事件状态调试信息 ===');
            console.log('dungeon.status.event:', dungeon.status.event);
            console.log('dungeon.status.exploring:', dungeon.status.exploring);
            console.log('dungeon.status.paused:', dungeon.status.paused);
            console.log('player.inCombat:', player.inCombat);
            console.log('========================');
        }
    }
});

// 显示测试模式弹窗
const showTestModeModal = () => {
    if (typeof sfxOpen !== 'undefined' && sfxOpen.play) {
        safePlaySFX(sfxOpen);
    }
    dungeon.status.exploring = false;
    let dimDungeon = document.querySelector('#dungeon-main');
    dimDungeon.style.filter = "brightness(50%)";
    
    document.querySelector("#defaultModal").style.display = "flex";
    document.querySelector("#defaultModal").innerHTML = `
    <div class="content">
        <div class="content-head">
            <h3><i class="fas fa-rocket"></i> 测试模式</h3>
            <p id="test-close"><i class="fa fa-xmark"></i></p>
        </div>
        <div style="text-align: center; margin-bottom: 1.5rem;">
            <p>使用快捷键快速测试游戏功能：</p>
            <div style="background: rgba(0, 212, 255, 0.1); padding: 1rem; border-radius: 8px; margin: 1rem 0;">
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">G</kbd> 传送到第99层</p>
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">V</kbd> 直接触发胜利</p>
                <p style="margin: 0.5rem 0;"><kbd style="background: #333; padding: 0.3rem 0.5rem; border-radius: 3px;">T</kbd> 显示此面板</p>
            </div>
            <p style="color: #ff6b6b; font-size: 0.9rem;">警告：这些操作会影响当前进度！</p>
        </div>
        <div class="button-container">
            <button id="test-to-99">传送到第99层</button>
            <button id="test-victory">直接触发胜利</button>
            <button id="test-cancel">关闭</button>
        </div>
    </div>`;
    
    let testClose = document.querySelector('#test-close');
    let testTo99 = document.querySelector('#test-to-99');
    let testVictory = document.querySelector('#test-victory');
    let testCancel = document.querySelector('#test-cancel');
    
    testClose.onclick = testCancel.onclick = function () {
        if (typeof sfxDecline !== 'undefined' && sfxDecline.play) {
            safePlaySFX(sfxDecline);
        }
        document.querySelector("#defaultModal").style.display = "none";
        document.querySelector("#defaultModal").innerHTML = "";
        dimDungeon.style.filter = "brightness(100%)";
        continueExploring();
    };
    
    testTo99.onclick = function () {
        teleportTo99();
        testCancel.onclick();
    };
    
    testVictory.onclick = function () {
        triggerTestVictory();
        testCancel.onclick();
    };
};

// 传送到99层
const teleportTo99 = () => {
    if (typeof sfxConfirm !== 'undefined' && sfxConfirm.play) {
        safePlaySFX(sfxConfirm);
    }
    
    // 快速设置到99层用于测试
    dungeon.progress.floor = 99;
    dungeon.progress.room = 5;
    player.lvl = 50;
    player.blessing = 10;
    player.gold = 1000000;
    player.kills += 500;
    dungeon.statistics.kills += 100;
    
    // 给予强力装备和属性
    player.bonusStats.hp += 200;
    player.bonusStats.atk += 200;
    player.bonusStats.def += 200;
    player.bonusStats.atkSpd += 50;
    player.bonusStats.critRate += 50;
    player.bonusStats.critDmg += 200;
    
    calculateStats();
    player.stats.hp = player.stats.hpMax;
    playerLoadStats();
    loadDungeonProgress();
    saveData();
    
    addDungeonLog("<span class='Heirloom'>测试模式激活：已传送到第99层！</span>");
};

// 直接触发胜利
const triggerTestVictory = () => {
    if (typeof sfxConfirm !== 'undefined' && sfxConfirm.play) {
        safePlaySFX(sfxConfirm);
    }
    
    // 直接触发胜利界面用于测试
    dungeon.progress.floor = 100;
    dungeon.statistics.runtime = 1800; // 30分钟测试时间
    player.lvl = 75;
    player.blessing = 15;
    dungeon.statistics.kills = 200;
    
    saveData();
    triggerVictory();
};

// ========== 隐私政策相关函数 ==========

// 检查隐私政策同意状态
function checkPrivacyConsent() {
    const consent = localStorage.getItem('privacy_consent');
    if (consent !== 'accepted') {
        showPrivacyModal();
    } else {
        // 用户已同意，初始化SDK
        if (typeof AndroidBridge !== 'undefined' && AndroidBridge.initializeAdSDK) {
            console.log('用户已同意隐私政策，初始化广告SDK...');
            AndroidBridge.initializeAdSDK();
        }
    }
}

// 显示隐私政策弹窗
function showPrivacyModal() {
    const privacyModal = document.getElementById('privacy-modal');
    if (privacyModal) {
        privacyModal.style.display = 'flex';
        
        // 绑定事件监听器
        const acceptBtn = document.getElementById('privacy-accept');
        const declineBtn = document.getElementById('privacy-decline');
        const privacyLink = document.getElementById('privacy-link');
        
        if (acceptBtn) {
            acceptBtn.addEventListener('click', handlePrivacyAccept);
        }
        
        if (declineBtn) {
            declineBtn.addEventListener('click', handlePrivacyDecline);
        }
        
        if (privacyLink) {
            privacyLink.addEventListener('click', function(e) {
                e.preventDefault();
                const url = this.href;
                
                // 在Android环境中使用原生方法打开外部浏览器
                if (typeof AndroidBridge !== 'undefined' && AndroidBridge.openExternalBrowser) {
                    AndroidBridge.openExternalBrowser(url);
                } else {
                    // 在Web环境中正常打开
                    window.open(url, '_blank');
                }
            });
        }
    }
}

// 处理同意隐私政策
function handlePrivacyAccept() {
    // 保存同意状态
    localStorage.setItem('privacy_consent', 'accepted');
    
    // 隐藏弹窗
    const privacyModal = document.getElementById('privacy-modal');
    if (privacyModal) {
        privacyModal.style.display = 'none';
    }
    
    // 播放确认音效
    if (typeof sfxConfirm !== 'undefined') {
        safePlaySFX(sfxConfirm);
    }
    
    console.log('用户已同意隐私政策');
    
    // 初始化广告SDK（仅在Android环境中）
    if (typeof AndroidBridge !== 'undefined' && AndroidBridge.initializeAdSDK) {
        console.log('初始化广告SDK...');
        AndroidBridge.initializeAdSDK();
    }
}

// 处理拒绝隐私政策
function handlePrivacyDecline() {
    // 播放音效
    if (typeof sfxCancel !== 'undefined') {
        safePlaySFX(sfxCancel);
    }
    
    // 退出游戏
    // 在移动端App中，尝试调用原生关闭方法
    if (typeof AndroidBridge !== 'undefined' && AndroidBridge.closeApp) {
        AndroidBridge.closeApp();
    } else if (typeof webkit !== 'undefined' && webkit.messageHandlers && webkit.messageHandlers.closeApp) {
        webkit.messageHandlers.closeApp.postMessage('');
    } else {
        // Web环境下关闭窗口或页面
        try {
            window.close();
        } catch (e) {
            // 如果无法关闭窗口，显示消息并跳转到空白页
            alert('感谢您的使用，再见！');
            window.location.href = 'about:blank';
        }
    }
}
